@@ -887,7 +887,7 @@ class ZPool():
 
     def __init__(self, processes=None, initializer=None, initargs=(),
                  maxtasksperchild=None, cluster=None,
-                 master_sock_type="w"):
+                 master_sock_type="w", pool_name=None):
 
         self._pool = []
         # Set default processes to 1
@@ -902,6 +902,7 @@ class ZPool():
         self.sent_tasks = 0
         self.recv_tasks = 0
         self.max_processing_tasks = 20000
+        self.pool_name = pool_name
 
         # networking related
         backend = get_backend()
@@ -1008,7 +1009,7 @@ class ZPool():
 
     @staticmethod
     def _maintain_workers(processes, workers, master_addr, result_addr, initializer,
-                          initargs, maxtasksperchild):
+                          initargs, maxtasksperchild, pool_name):
         thread = threading.current_thread()
 
         workers_per_fp = config.cpu_per_job
@@ -1037,7 +1038,7 @@ class ZPool():
                                             n),
                                       daemon=False)
 
-            w.name = w.name.replace("Process", "PoolWorker")
+            w.name = w.name.replace("Process", pool_name or "PoolWorker")
 
             td = threading.Thread(target=safe_start, args=(w,))
             td.start()
@@ -1064,7 +1065,7 @@ class ZPool():
         ZPool._maintain_workers(
             pool._processes, pool._pool,
             pool._master_addr, pool._result_addr, pool._initializer,
-            pool._initargs, pool._maxtasksperchild
+            pool._initargs, pool._maxtasksperchild, pool.pool_name
         )
 
         while td._state == RUN:
@@ -1435,7 +1436,7 @@ class ResilientZPool(ZPool):
     if `processes` argument is not set, its default value is 1.
     """
     def __init__(self, processes=None, initializer=None, initargs=(),
-                 maxtasksperchild=None, cluster=None):
+                 maxtasksperchild=None, cluster=None, pool_name=None):
 
         self.active_peer_dict = {}
         self.active_peer_list = []
@@ -1449,7 +1450,8 @@ class ResilientZPool(ZPool):
             initargs=initargs,
             maxtasksperchild=maxtasksperchild,
             cluster=cluster,
-            master_sock_type="rep")
+            master_sock_type="rep",
+            pool_name=pool_name)
 
         '''
         # launch task handler
@@ -1556,7 +1558,7 @@ class ResilientZPool(ZPool):
 
     @staticmethod
     def _maintain_workers(processes, workers, master_addr, result_addr, initializer,
-                          initargs, maxtasksperchild):
+                          initargs, maxtasksperchild, pool_name):
         thread = threading.current_thread()
 
         workers_per_fp = config.cpu_per_job
@@ -1589,7 +1591,7 @@ class ResilientZPool(ZPool):
                                             True),
                                       daemon=False)
 
-            w.name = w.name.replace("Process", "PoolWorker")
+            w.name = w.name.replace("Process", pool_name or "PoolWorker")
 
             td = threading.Thread(target=safe_start, args=(w,))
             td.start()
@@ -1617,7 +1619,7 @@ class ResilientZPool(ZPool):
         ResilientZPool._maintain_workers(
             pool._processes, pool._pool,
             pool._master_addr, pool._result_addr, pool._initializer,
-            pool._initargs, pool._maxtasksperchild
+            pool._initargs, pool._maxtasksperchild, pool.pool_name
         )
 
         while td._state == RUN:
