@@ -37,7 +37,7 @@ from fiber.backend import get_backend
 from fiber.core import JobSpec
 from fiber.core import ProcessStatus
 
-logger = logging.getLogger("fiber")
+logger = logging.getLogger('Trax')
 
 # each line much ends with `;`
 fiber_init_start = """
@@ -276,6 +276,7 @@ class Popen(object):
 
     def _run_job(self, job):
         try:
+            logger.debug(f'starting job {job} in backend {self.backend}')
             job = self.backend.create_job(job)
         except requests.exceptions.ReadTimeout as e:
             raise mp.TimeoutError(str(e))
